## Custom Bootstrap

`ui/bootstraptheme.css` is a customized version of Bootstrap with additional features.

You can customize Bootstrap by modifying variable from the URL. For example: `ui/bootstraptheme.css?primary=maroon` creates a CSS that has the primary color as maroon. (See the effect on this page.)

See the list of Bootstrap variables you can change. Here are some examples:

- `?body-bg=yellow`
- `?link-color=black`
- `?paragraph-margin-bottom=5rem`
- Reset theme

In addition, any variable beginning with `color` is added as a theme color. For example, initially these buttons have no color:

But click on this link: `?color1=purple&color-abc=teal` to add a new `color1` and `color-abc` to the theme. All color methods like `.bg-color1`, `.text-color-abc`, etc work.

You can change some common variables from the `Change Theme` button on at the top of this page to colors, fonts and style.

There are also additional components and utilities in the library. See the sidebar for a full list.